@@ -1,7 +1,7 @@
 package Config::IOD;
 
 our $DATE = '2015-03-12'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -175,7 +175,7 @@ Config::IOD - Read and write IOD configuration files
 
 =head1 VERSION
 
-This document describes version 0.09 of Config::IOD (from Perl distribution Config-IOD), released on 2015-03-12.
+This document describes version 0.10 of Config::IOD (from Perl distribution Config-IOD), released on 2015-03-12.
 
 =head1 SYNOPSIS
 
@@ -202,55 +202,17 @@ Read IOD document from a file or string, return L<Config::IOD::Document> object:
 
 See Config::IOD::Document for methods available for C<$doc>.
 
-=head1 EXPRESSION
+=head1 DESCRIPTION
 
-Expression allows you to do things like:
+This module is a round-trip parser for L<IOD> configuration format. Round-trip
+means all whitespaces and comments are preserved, so you get byte-by-byte
+equivalence if you dump back the parsed document into string.
 
- [section1]
- foo=1
- bar="monkey"
+Aside from parsing, methods for modifying IOD documents (add/delete sections &
+keys, etc) are also provided.
 
- [section2]
- baz =!e 1+1
- qux =!e "grease" . val("section1.bar")
- quux=!e val("qux") . " " . val('baz')
-
-And the result will be:
-
- {
-     section1 => {foo=>1, bar=>"monkey"},
-     section2 => {baz=>2, qux=>"greasemonkey", quux=>"greasemonkey 2"},
- }
-
-For safety, you'll need to set C<enable_expr> attribute to 1 first to enable
-this feature.
-
-The syntax of the expression (the C<expr> encoding) is not officially specified
-yet in the L<IOD> specification. It will probably be Expr (see
-L<Language::Expr::Manual::Syntax>). At the moment, this module implements a very
-limited subset that is compatible (lowest common denominator) with Perl syntax
-and uses C<eval()> to evaluate the expression. However, only the limited subset
-is allowed (checked by Perl 5.10 regular expression).
-
-The supported terms:
-
- number
- string (double-quoted and single-quoted)
- undef literal
- function call (only the 'val' function is supported)
- grouping (parenthesis)
-
-The supported operators are:
-
- + - .
- * / % x
- **
- unary -, unary +, !, ~
-
-The C<val()> function refers to the configuration key. If the argument contains
-".", it will be assumed as C<SECTIONNAME.KEYNAME>, otherwise it will access the
-current section's key. Since parsing is done in a single pass, you can only
-refer to the already mentioned key.
+If you only need to read IOD configuration files, you might want to use
+L<Config::IOD::Reader> instead.
 
 =head1 ATTRIBUTES
 
@@ -344,6 +306,18 @@ be more strict.
 
 =head1 METHODS
 
+=head2 new(%attrs) => obj
+
+=head2 $reader->read_file($filename) => obj
+
+Read IOD configuration from a file. Return L<Config::IOD::Document> instance.
+Die on errors.
+
+=head2 $reader->read_string($str) => obj
+
+Read IOD configuration from a string. Return L<Config::IOD::Document> instance.
+Die on errors.
+
 =head1 SEE ALSO
 
 L<IOD> - specification
