@@ -1,7 +1,7 @@
 package Config::IOD::Document;
 
 our $DATE = '2015-03-12'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 use 5.010;
 use strict;
@@ -45,7 +45,15 @@ use constant +{
 
 sub new {
     my ($class, %attrs) = @_;
-    #croak "Please specify _parsed" unless $attrs{_parsed};
+
+    if (!$attrs{_parsed}) {
+        $attrs{_parsed} = [];
+    }
+    if (!$attrs{_parser}) {
+        require Config::IOD;
+        $attrs{_parser} = Config::IOD->new;
+    }
+
     bless \%attrs, $class;
 }
 
@@ -487,12 +495,15 @@ Config::IOD::Document - Represent IOD document
 
 =head1 VERSION
 
-This document describes version 0.09 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2015-03-12.
+This document describes version 0.10 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2015-03-12.
 
 =head1 SYNOPSIS
 
 Obtain a document object C<$doc> from parsing an IOD document text using
-L<Config::IOD>'s C<read_file> or C<read_string> method.
+L<Config::IOD>'s C<read_file> or C<read_string> method. Or, to produce an empty
+document:
+
+ $doc = Config::IOD::Document->new;
 
 Insert a section:
 
